<?php

// Sécurité
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Compile la balise `#DASHBOARD` qui fournit la configuration complète d'un dashboard ou de tous les dashboards.
 * La signature de la balise est : `#DASHBOARD{dashboard_id}`.
 *
 * @balise
 *
 * @example
 *     ```
 *     #DASHBOARD{contrib}, renvoie la description complète du dashboard d'id `contrib`
 *     #DASHBOARD, renvoie la description de tous les dashboards
 *     ```
 *
 * @param Champ $p Pile au niveau de la balise.
 *
 * @return Champ Pile complétée par le code à générer.
 **/
function balise_DASHBOARD_dist($p) {

	// Récupération des arguments de la balise.
	// -- seul l'argument information est optionnel.
	$dashboard_id = interprete_argument_balise(1, $p);
	$dashboard_id = isset($dashboard_id) ? str_replace('\'', '"', $dashboard_id) : '""';

	// Calcul de la balise
	$p->code = "calculer_dashboard(${dashboard_id})";

	return $p;
}

/**
 * @internal
 *
 * @param string $dashboard_id
 *
 * @return array
 */
function calculer_dashboard($dashboard_id = '') {
	include_spip('inc/ezcheck_dashboard');
	if ($dashboard_id) {
		$retour = dashboard_lire($dashboard_id);
	} else {
		$retour = dashboard_repertorier();
	}

	return $retour;
}

/**
 * Compile la balise `#DASHBOARD_CONTEXTE` qui fournit la configuration complète d'un dashboard ainsi que des
 * informations supplémentaires provenant de l'environnement de la page dashboard.
 * La signature de la balise est : `#DASHBOARD_CONTEXTE{dashboard_id, groupe_id, type_controle}`.
 *
 * @balise
 *
 * @param Champ $p Pile au niveau de la balise.
 *
 * @return Champ Pile complétée par le code à générer.
 *
 **@example
 *     ```
 *     #DASHBOARD_CONTEXTE{contrib, '', ''}, renvoie la description complète du dashboard d'id `contrib` ainsi que
 *     l'id du premier groupe et le premier type de contrôle listé dans le groupe.
 *     #DASHBOARD_CONTEXTE{contrib, article, ''}, renvoie la description complète du dashboard d'id `contrib` ainsi que
 *     l'id du premier groupe et le premier type de contrôle listé dans le groupe.
 *     #DASHBOARD_CONTEXTE{contrib, 'article', 'article_prepa'}, renvoie la description complète du dashboard d'id `contrib` ainsi que
 *     l'id du premier groupe et le premier type de contrôle listé dans le groupe.
 *     ```
 */
function balise_DASHBOARD_CONTEXTE_dist($p) {

	// Récupération des arguments de la balise.
	// -- Tous les arguments sont obligatoires.
	$dashboard_id = interprete_argument_balise(1, $p);
	$dashboard_id = isset($dashboard_id) ? str_replace('\'', '"', $dashboard_id) : '""';
	$groupe_id = interprete_argument_balise(2, $p);
	$groupe_id = isset($groupe_id) ? str_replace('\'', '"', $groupe_id) : '""';
	$type_controle = interprete_argument_balise(3, $p);
	$type_controle = isset($type_controle) ? str_replace('\'', '"', $type_controle) : '""';

	// Calcul de la balise
	$p->code = "calculer_contexte_dashboard(${dashboard_id}, ${groupe_id}, ${type_controle})";

	return $p;
}

/**
 * @internal
 *
 * @param string $dashboard_id
 * @param mixed  $groupe_id
 * @param mixed  $type_controle
 *
 * @return array
 */
function calculer_contexte_dashboard($dashboard_id, $groupe_id, $type_controle) {

	// On initialise le contexte à vide en cas d'erreur
	$contexte = array();

	// On récupère la description du dashboard désigné par son identifiant
	include_spip('inc/ezcheck_dashboard');
	if ($dashboard_id) {
		$contexte = dashboard_lire($dashboard_id);

		// On rajoute le groupe à afficher ou à défaut le premier
		if (isset($contexte['groupes'][$groupe_id])) {
			$contexte['groupe_id_defaut'] = $groupe_id;
		} else {
			$groupe = reset($contexte['groupes']);
			$contexte['groupe_id_defaut'] = $groupe['identifiant'];
		}

		// Maintenant qu'on a le groupe on rajoute le type de controle à afficher ou à défaut le premier du groupe
		if (in_array($type_controle, $contexte['groupes'][$contexte['groupe_id_defaut']]['controles'])) {
			$contexte['type_controle_defaut'] = $type_controle;
		} else {
			$contexte['type_controle_defaut'] = reset($contexte['groupes'][$contexte['groupe_id_defaut']]['controles']);
		}
	}

	return $contexte;
}

/**
 * Construire le titre d'un contrôle.
 *
 * @param int   $id_objet
 * @param array $champs
 *
 * @return string
 */
function generer_titre_controle($id_objet, $champs) {

	// Le titre d'un contrôle est de la forme type_controle:id
	$titre = "{$champs['type_controle']}:${id_objet}";

	return $titre;
}

/**
 * Construire le titre d'une observation.
 *
 * @param int   $id_objet
 * @param array $champs
 *
 * @return string
 */
function generer_titre_observation($id_objet, $champs) {

	// Le titre d'une observation est de la forme code:id
	$titre = "{$champs['code']}:{$champs['id_controle']}-${id_objet}";

	return $titre;
}

/**
 * Passer typo si la valeur est un idiome spip.
 *
 * @param mixed $valeur
 *
 * @return mixed
 */
function idiome_preparer($valeur) {

	// Si la variable est un idiome spip <:modute:item:> on passe typo
	if (
		is_string($valeur)
		and (strpos($valeur, '<:') !== false)
		and preg_match('/^\<:([^>]*?):\>$/', $valeur, $match)
	) {
		$valeur = typo($valeur);
	}

	return $valeur;
}

/**
 * Renvoie l'identifiant du dashboard auquel est rattaché le type contrôle.
 *
 * @param string $id_type_controle Identifiant du type de contrôle.
 *
 * @return string Idenfiant du dashboard de rattachement ou chaine vide sinon.
 */
function type_controle_identifier_dashboard($id_type_controle) {

	// Acquérir tous les dashboards
	include_spip('inc/ezcheck_dashboard');
	$dashboards = dashboard_repertorier();

	$id_dashboard = '';
	$controle_trouve = false;
	foreach ($dashboards as $_id => $_dashboard) {
		if (isset($_dashboard['groupes'])) {
			foreach ($_dashboard['groupes'] as $_groupe) {
				if (in_array($id_type_controle, $_groupe['controles'])) {
					$id_dashboard = $_id;
					$controle_trouve = true;
					break;
				}
			}

			if ($controle_trouve) {
				break;
			}
		}
	}

	return $id_dashboard;
}